
TrojanZoo documentation
========================
TrojanZoo is a universal pytorch platform for conducting security researches (especially for backdoor attacks/defenses) for image classification in deep learning.

.. toctree::
   :caption: Tutorials
   :titlesonly:

   basic <tutorials/basic>

.. toctree::
   :caption: TrojanZoo Documentation
   :titlesonly:

   trojanzoo <trojanzoo/index>
   trojanvision <trojanvision/index>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
